@@ -10,7 +10,7 @@
 #include <QVBoxLayout>
 #include <QLineEdit>
 #include <QLabel>
-#include <QTextEdit>
+#include <QTextBrowser>
 #include <QStatusBar>
 #include <QProcess>
 #include <QTimer>
@@ -31,6 +31,10 @@
 
 const int messageTimeout = 5000; //!< status bar message timeout in milliseconds.
 
+#define APPQT(x) QString::fromLatin1("<qt><pre>") + x + QString::fromLatin1("</pre></qt>")
+
+static QString text1  = QString::fromLatin1("");
+
 MainWindow &MainWindow::instance()
 {
   static MainWindow *theInstance = new MainWindow;
@@ -101,7 +105,9 @@ MainWindow::MainWindow()
   runTabLayout->addLayout(runLayout);
   runTabLayout->addWidget(new QLabel(tr("Output produced by doxygen")));
   QGridLayout *grid = new QGridLayout;
-  m_outputLog = new QTextEdit;
+  //m_outputLog = new QTextEdit;
+  m_outputLog = new QTextBrowser;
+  //m_outputLog = new QPlainTextEdit;
   m_outputLog->setReadOnly(true);
   m_outputLog->setFontFamily(QString::fromLatin1("courier"));
   m_outputLog->setMinimumWidth(600);
@@ -368,14 +374,16 @@ void MainWindow::loadSettings()
     }
   }
 
-  for (int i=0;i<MAX_RECENT_FILES;i++)
+  /* due to prepend use list in reversed order */
+  for (int i=MAX_RECENT_FILES;i>=0;i--)
   {
     QString entry = m_settings.value(QString().sprintf("recent/config%d",i)).toString();
     if (!entry.isEmpty() && QFileInfo(entry).exists())
     {
-      addRecentFile(entry);
+      addRecentFileList(entry);
     }
   }
+  updateRecentFile();
 
 }
 
@@ -401,6 +409,11 @@ void MainWindow::selectRunTab()
 }
 
 void MainWindow::addRecentFile(const QString &fileName)
+{
+  addRecentFileList(fileName);
+  updateRecentFile();
+}
+void MainWindow::addRecentFileList(const QString &fileName)
 {
   int i=m_recentFiles.indexOf(fileName);
   if (i!=-1) m_recentFiles.removeAt(i);
@@ -415,8 +428,11 @@ void MainWindow::addRecentFile(const QString &fileName)
     m_recentFiles.removeLast();
     m_recentFiles.prepend(fileName);
   }
+}
+void MainWindow::updateRecentFile(void)
+{
   m_recentMenu->clear();
-  i=0;
+  int i=0;
   foreach( QString str, m_recentFiles ) 
   {
     m_recentMenu->addAction(str);
@@ -474,11 +490,12 @@ void MainWindow::runDoxygen()
     args << QString::fromLatin1("-");  // read config from stdin
 
     m_outputLog->clear();
+    text1  = QString::fromLatin1("");
     m_runProcess->start(doxygenPath + QString::fromLatin1("doxygen"), args);
 
     if (!m_runProcess->waitForStarted())
     {
-      m_outputLog->append(QString::fromLatin1("*** Failed to run doxygen\n"));
+      m_outputLog->append(APPQT(QString::fromLatin1("*** Failed to run doxygen\n")));
       return;
     }
     QTextStream t(m_runProcess);
@@ -487,7 +504,7 @@ void MainWindow::runDoxygen()
 
     if (m_runProcess->state() == QProcess::NotRunning)
     {
-      m_outputLog->append(QString::fromLatin1("*** Failed to run doxygen\n"));
+      m_outputLog->append(APPQT(QString::fromLatin1("*** Failed to run doxygen\n")));
     }
     else
     {
@@ -517,7 +534,9 @@ void MainWindow::readStdout()
     QString text = QString::fromUtf8(data);
     if (!text.isEmpty())
     {
-      m_outputLog->append(text.trimmed());
+      text1 += text;
+      m_outputLog->clear();
+      m_outputLog->append(APPQT(text1.trimmed()));
     }
   }
 }
@@ -526,11 +545,11 @@ void MainWindow::runComplete()
 {
   if (m_running)
   {
-    m_outputLog->append(tr("*** Doxygen has finished\n"));
+    m_outputLog->append(APPQT(tr("*** Doxygen has finished\n")));
   }
   else
   {
-    m_outputLog->append(tr("*** Cancelled by user\n"));
+    m_outputLog->append(APPQT(tr("*** Cancelled by user\n")));
   }
   m_outputLog->ensureCursorVisible();
   m_run->setText(tr("Run doxygen"));
@@ -592,7 +611,7 @@ void MainWindow::showSettings()
   QTextStream t(&text);
   m_expert->writeConfig(t,true);
   m_outputLog->clear();
-  m_outputLog->append(text);
+  m_outputLog->append(APPQT(text));
   m_outputLog->ensureCursorVisible();
   m_saveLog->setEnabled(true);
 }
