@@ -33,6 +33,7 @@ ArgumentList *ArgumentList::deepCopy() const
   argList->pureSpecifier      = pureSpecifier;
   argList->trailingReturnType = trailingReturnType;
   argList->isDeleted          = isDeleted;
+  argList->refQualifier       = refQualifier;
 
   return argList;
 }
@@ -63,6 +64,7 @@ ArgumentList *ArgumentList::unmarshal(StorageIntf *s)
   result->pureSpecifier      = unmarshalBool(s);
   result->trailingReturnType = unmarshalQCString(s);
   result->isDeleted          = unmarshalBool(s);
+  result->refQualifier       = (RefQualifierType)unmarshalInt(s);
   return result;
 }
 
@@ -81,13 +83,13 @@ void ArgumentList::marshal(StorageIntf *s,ArgumentList *argList)
       Argument *a;
       for (ali.toFirst();(a=ali.current());++ali)
       {
-        marshalQCString(s,a->attrib);    
-        marshalQCString(s,a->type);    
-        marshalQCString(s,a->canType);    
-        marshalQCString(s,a->name);    
-        marshalQCString(s,a->array);    
-        marshalQCString(s,a->defval);    
-        marshalQCString(s,a->docs);    
+        marshalQCString(s,a->attrib);
+        marshalQCString(s,a->type);
+        marshalQCString(s,a->canType);
+        marshalQCString(s,a->name);
+        marshalQCString(s,a->array);
+        marshalQCString(s,a->defval);
+        marshalQCString(s,a->docs);
         marshalQCString(s,a->typeConstraint);
       }
     }
@@ -96,6 +98,7 @@ void ArgumentList::marshal(StorageIntf *s,ArgumentList *argList)
     marshalBool(s,argList->pureSpecifier);
     marshalQCString(s,argList->trailingReturnType);
     marshalBool(s,argList->isDeleted);
+    marshalInt(s,(int)argList->refQualifier);
   }
 }
 
