@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -159,7 +159,7 @@ class LatexDocVisitor : public DocVisitor
     
     void filter(const char *str);
     void startLink(const QCString &ref,const QCString &file,
-                   const QCString &anchor);
+                   const QCString &anchor,bool refToTable=FALSE);
     void endLink(const QCString &ref,const QCString &file,
                  const QCString &anchor);
     QCString escapeMakeIndexChars(const char *s);
@@ -170,12 +170,13 @@ class LatexDocVisitor : public DocVisitor
     void startMscFile(const QCString &fileName,const QCString &width,
                       const QCString &height, bool hasCaption);
     void endMscFile(bool hasCaption);
-    void writeMscFile(const QCString &fileName);
+    void writeMscFile(const QCString &fileName, DocVerbatim *s);
 
     void startDiaFile(const QCString &fileName,const QCString &width,
                       const QCString &height, bool hasCaption);
     void endDiaFile(bool hasCaption);
-    void writeDiaFile(const QCString &fileName);
+    void writeDiaFile(const QCString &fileName, DocVerbatim *s);
+    void writePlantUMLFile(const QCString &fileName, DocVerbatim *s);
 
     void pushEnabled();
     void popEnabled();
@@ -189,15 +190,87 @@ class LatexDocVisitor : public DocVisitor
     bool m_insidePre;
     bool m_insideItem;
     bool m_hide;
+    bool m_hideCaption;
     bool m_insideTabbing;
-    bool m_insideTable;
-    int  m_numCols;
     QStack<bool> m_enabled;
     QCString m_langExt;
-    RowSpanList m_rowSpans;
-    int m_currentColumn;
-    bool m_inRowspan;
-    bool m_inColspan;
+
+    struct TableState
+    {
+      TableState() : numCols(0), currentColumn(0), inRowSpan(FALSE), 
+                     inColSpan(FALSE), firstRow(FALSE)
+      { rowSpans.setAutoDelete(TRUE); }
+      RowSpanList rowSpans;
+      int  numCols;
+      int currentColumn;
+      bool inRowSpan;
+      bool inColSpan;
+      bool firstRow;
+    };
+    QStack<TableState> m_tableStateStack; // needed for nested tables
+    RowSpanList m_emptyRowSpanList;
+
+    void pushTableState()
+    {
+      m_tableStateStack.push(new TableState);
+    }
+    void popTableState()
+    {
+      delete m_tableStateStack.pop();
+    }
+    int currentColumn() const
+    {
+      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->currentColumn : 0;
+    }
+    void setCurrentColumn(int col)
+    {
+      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->currentColumn = col;
+    }
+    int numCols() const
+    {
+      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->numCols : 0;
+    }
+    void setNumCols(int num)
+    {
+      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->numCols = num;
+    }
+    bool inRowSpan() const
+    {
+      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->inRowSpan : FALSE;
+    }
+    void setInRowSpan(bool b)
+    {
+      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->inRowSpan = b;
+    }
+    bool inColSpan() const
+    {
+      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->inColSpan : FALSE;
+    }
+    void setInColSpan(bool b)
+    {
+      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->inColSpan = b;
+    }
+    bool firstRow() const
+    {
+      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->firstRow : FALSE;
+    }
+    void setFirstRow(bool b)
+    {
+      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->firstRow = b;
+    }
+    const RowSpanList &rowSpans()
+    {
+      return !m_tableStateStack.isEmpty() ? m_tableStateStack.top()->rowSpans : m_emptyRowSpanList;
+    }
+    void addRowSpan(ActiveRowSpan *span)
+    {
+      if (!m_tableStateStack.isEmpty()) m_tableStateStack.top()->rowSpans.append(span);
+    }
+    bool insideTable() const
+    {
+      return !m_tableStateStack.isEmpty();
+    }
+
 };
 
 #endif
