@@ -42,7 +42,14 @@ NamespaceDef::NamespaceDef(const char *df,int dl,int dc,
 {
   if (fName)
   {
-    fileName = stripExtension(fName);
+    if (lref)
+    {
+      fileName = stripExtension(fName);
+    }
+    else
+    {
+      fileName = convertNameToFile(stripExtension(fName));
+    }
   }
   else
   {
@@ -58,7 +65,7 @@ NamespaceDef::NamespaceDef(const char *df,int dl,int dc,
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
   visited=FALSE;
-  m_subGrouping=Config_getBool("SUBGROUPING");
+  m_subGrouping=Config_getBool(SUBGROUPING);
   if (type && !strcmp("module", type))
   {
     m_type = MODULE;
@@ -90,8 +97,14 @@ NamespaceDef::~NamespaceDef()
 
 void NamespaceDef::setFileName(const QCString &fn)
 {
-  fileName="namespace";
-  fileName+=fn;
+  if (isReference())
+  {
+    fileName = "namespace"+fn;
+  }
+  else
+  {
+    fileName = convertNameToFile("namespace"+fn);
+  }
 }
 
 void NamespaceDef::distributeMemberGroupDocumentation()
@@ -129,7 +142,7 @@ void NamespaceDef::insertUsedFile(FileDef *fd)
   if (fd==0) return;
   if (files.find(fd)==-1) 
   {
-    if (Config_getBool("SORT_MEMBER_DOCS"))
+    if (Config_getBool(SORT_MEMBER_DOCS))
       files.inSort(fd);
     else
       files.append(fd);
@@ -153,7 +166,7 @@ void NamespaceDef::insertClass(ClassDef *cd)
 {
   if (classSDict->find(cd->name())==0)
   {
-    if (Config_getBool("SORT_BRIEF_DOCS"))
+    if (Config_getBool(SORT_BRIEF_DOCS))
       classSDict->inSort(cd->name(),cd);
     else
       classSDict->append(cd->name(),cd);
@@ -164,7 +177,7 @@ void NamespaceDef::insertNamespace(NamespaceDef *nd)
 {
   if (namespaceSDict->find(nd->name())==0)
   {
-    if (Config_getBool("SORT_MEMBER_DOCS"))
+    if (Config_getBool(SORT_MEMBER_DOCS))
       namespaceSDict->inSort(nd->name(),nd);
     else
       namespaceSDict->append(nd->name(),nd);
@@ -217,7 +230,7 @@ void NamespaceDef::insertMember(MemberDef *md)
   //printf("%s::m_allMembersDict->append(%s)\n",name().data(),md->localName().data());
   m_allMembersDict->append(md->localName(),md); 
   //::addNamespaceMemberNameToIndex(md);
-  //static bool sortBriefDocs=Config_getBool("SORT_BRIEF_DOCS");
+  //static bool sortBriefDocs=Config_getBool(SORT_BRIEF_DOCS);
   switch(md->memberType())
   {
     case MemberType_Variable:     
@@ -259,7 +272,7 @@ void NamespaceDef::computeAnchors()
 
 bool NamespaceDef::hasDetailedDescription() const
 {
-  static bool repeatBrief = Config_getBool("REPEAT_BRIEF");
+  static bool repeatBrief = Config_getBool(REPEAT_BRIEF);
   return ((!briefDescription().isEmpty() && repeatBrief) ||
           !documentation().isEmpty());
 }
@@ -361,11 +374,11 @@ void NamespaceDef::writeDetailedDescription(OutputList &ol,const QCString &title
     ol.endGroupHeader();
 
     ol.startTextBlock();
-    if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF"))
+    if (!briefDescription().isEmpty() && Config_getBool(REPEAT_BRIEF))
     {
       ol.generateDoc(briefFile(),briefLine(),this,0,briefDescription(),FALSE,FALSE);
     }
-    if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF") &&
+    if (!briefDescription().isEmpty() && Config_getBool(REPEAT_BRIEF) &&
         !documentation().isEmpty())
     {
       ol.pushGeneratorState();
@@ -395,6 +408,10 @@ void NamespaceDef::writeBriefDescription(OutputList &ol)
     if (rootNode && !rootNode->isEmpty())
     {
       ol.startParagraph();
+      ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Man);
+      ol.writeString(" - ");
+      ol.popGeneratorState();
       ol.writeDoc(rootNode,this,0);
       ol.pushGeneratorState();
       ol.disable(OutputGenerator::RTF);
@@ -434,7 +451,7 @@ void NamespaceDef::endMemberDeclarations(OutputList &ol)
 
 void NamespaceDef::startMemberDocumentation(OutputList &ol)
 {
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  if (Config_getBool(SEPARATE_MEMBER_PAGES))
   {
     ol.disable(OutputGenerator::Html);
     Doxygen::suppressDocWarnings = TRUE;
@@ -443,7 +460,7 @@ void NamespaceDef::startMemberDocumentation(OutputList &ol)
 
 void NamespaceDef::endMemberDocumentation(OutputList &ol)
 {
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  if (Config_getBool(SEPARATE_MEMBER_PAGES))
   {
     ol.enable(OutputGenerator::Html);
     Doxygen::suppressDocWarnings = FALSE;
@@ -493,7 +510,7 @@ void NamespaceDef::writeAuthorSection(OutputList &ol)
   ol.startGroupHeader();
   ol.parseText(theTranslator->trAuthor(TRUE,TRUE));
   ol.endGroupHeader();
-  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString("PROJECT_NAME")));
+  ol.parseText(theTranslator->trGeneratedAutomatically(Config_getString(PROJECT_NAME)));
   ol.popGeneratorState();
 }
 
@@ -551,9 +568,9 @@ void NamespaceDef::addNamespaceAttributes(OutputList &ol)
 
 void NamespaceDef::writeDocumentation(OutputList &ol)
 {
-  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
-  //static bool outputJava = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
-  //static bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  static bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
+  //static bool outputJava = Config_getBool(OPTIMIZE_OUTPUT_JAVA);
+  //static bool fortranOpt = Config_getBool(OPTIMIZE_FOR_FORTRAN);
 
   QCString pageTitle = title();
   startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_NamespaceVisible,!generateTreeView);
@@ -690,7 +707,7 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
 
   endFileWithNavPath(this,ol);
 
-  if (Config_getBool("SEPARATE_MEMBER_PAGES"))
+  if (Config_getBool(SEPARATE_MEMBER_PAGES))
   {
     MemberList *allMemberList = getMemberList(MemberListType_allMembersList);
     if (allMemberList) allMemberList->sort();
@@ -717,7 +734,7 @@ void NamespaceDef::writeMemberPages(OutputList &ol)
 
 void NamespaceDef::writeQuickMemberLinks(OutputList &ol,MemberDef *currentMd) const
 {
-  static bool createSubDirs=Config_getBool("CREATE_SUBDIRS");
+  static bool createSubDirs=Config_getBool(CREATE_SUBDIRS);
 
   ol.writeString("      <div class=\"navtab\">\n");
   ol.writeString("        <table>\n");
@@ -796,16 +813,9 @@ void NamespaceDef::addUsingDeclaration(Definition *d)
   }
 }
 
-QCString NamespaceDef::getOutputFileBase() const 
-{ 
-  if (isReference())
-  {
-    return fileName;
-  }
-  else
-  {
-    return convertNameToFile(fileName); 
-  }
+QCString NamespaceDef::getOutputFileBase() const
+{
+  return fileName;
 }
 
 Definition *NamespaceDef::findInnerCompound(const char *n)
@@ -828,7 +838,7 @@ Definition *NamespaceDef::findInnerCompound(const char *n)
 
 void NamespaceDef::addListReferences()
 {
-  //bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  //bool fortranOpt = Config_getBool(OPTIMIZE_FOR_FORTRAN);
   {
     QList<ListItemInfo> *xrefItems = xrefListItems();
     addRefItem(xrefItems,
@@ -943,7 +953,7 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,const char *title,
 
   if (count()==0) return; // no namespaces in the list
 
-  if (Config_getBool("OPTIMIZE_OUTPUT_VHDL")) return;
+  if (Config_getBool(OPTIMIZE_OUTPUT_VHDL)) return;
  
 
   SDict<NamespaceDef>::Iterator ni(*this);
@@ -977,8 +987,8 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,const char *title,
 
   // write list of namespaces
   ol.startMemberHeader("namespaces");
-  //bool javaOpt    = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
-  //bool fortranOpt = Config_getBool("OPTIMIZE_FOR_FORTRAN");
+  //bool javaOpt    = Config_getBool(OPTIMIZE_OUTPUT_JAVA);
+  //bool fortranOpt = Config_getBool(OPTIMIZE_FOR_FORTRAN);
   ol.parseText(title);
   ol.endMemberHeader();
   ol.startMemberList();
@@ -1006,7 +1016,7 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,const char *title,
       }
       ol.writeObjectLink(nd->getReference(),nd->getOutputFileBase(),0,name);
       ol.endMemberItem();
-      if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+      if (!nd->briefDescription().isEmpty() && Config_getBool(BRIEF_MEMBER_DESC))
       {
         ol.startMemberDescription(nd->getOutputFileBase());
         ol.generateDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE,0,TRUE);
@@ -1038,8 +1048,8 @@ MemberList *NamespaceDef::createMemberList(MemberListType lt)
 
 void NamespaceDef::addMemberToList(MemberListType lt,MemberDef *md)
 {
-  static bool sortBriefDocs = Config_getBool("SORT_BRIEF_DOCS");
-  static bool sortMemberDocs = Config_getBool("SORT_MEMBER_DOCS");
+  static bool sortBriefDocs = Config_getBool(SORT_BRIEF_DOCS);
+  static bool sortMemberDocs = Config_getBool(SORT_MEMBER_DOCS);
   MemberList *ml = createMemberList(lt);
   ml->setNeedsSorting(
       ((ml->listType()&MemberListType_declarationLists) && sortBriefDocs) ||
@@ -1107,7 +1117,7 @@ bool NamespaceDef::isLinkableInProject() const
 {
   int i = name().findRev("::");
   if (i==-1) i=0; else i+=2;
-  static bool extractAnonNs = Config_getBool("EXTRACT_ANON_NSPACES");
+  static bool extractAnonNs = Config_getBool(EXTRACT_ANON_NSPACES);
   if (extractAnonNs &&                             // extract anonymous ns
       name().mid(i,20)=="anonymous_namespace{"     // correct prefix
      )                                             // not disabled by config
