@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -44,11 +44,6 @@ void OutputGenerator::startPlainFile(const char *name)
   //printf("startPlainFile(%s)\n",name);
   fileName=dir+"/"+name;
   file = new QFile(fileName);
-  if (!file)
-  {
-    err("Could not create file object for %s\n",fileName.data());
-    exit(1);
-  }
   if (!file->open(IO_WriteOnly))
   {
     err("Could not open file %s for writing\n",fileName.data());
