@@ -34,8 +34,7 @@ PageDef::PageDef(const char *f,int l,const char *n,
   m_subPageDict = new PageSDict(7);
   m_pageScope = 0;
   m_nestingLevel = 0;
-  static bool shortNames = Config_getBool("SHORT_NAMES");
-  m_fileName = shortNames ? convertNameToFile(n) : QCString(n);
+  m_fileName = ::convertNameToFile(n,FALSE,TRUE);
   m_showToc = FALSE;
 }
 
@@ -118,7 +117,7 @@ void PageDef::writeTagFile(FTextStream &tagFile)
 
 void PageDef::writeDocumentation(OutputList &ol)
 {
-  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
+  static bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
 
   //outputList->disable(OutputGenerator::Man);
   QCString pageName,manPageName;
@@ -154,7 +153,7 @@ void PageDef::writeDocumentation(OutputList &ol)
 
   if (!generateTreeView)
   {
-    if (getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
+    if (getOuterScope()!=Doxygen::globalScope && !Config_getBool(DISABLE_INDEX))
     {
       getOuterScope()->writeNavigationPath(ol);
     }
@@ -204,7 +203,7 @@ void PageDef::writeDocumentation(OutputList &ol)
 
   writePageDocumentation(ol);
 
-  if (generateTreeView && getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
+  if (generateTreeView && getOuterScope()!=Doxygen::globalScope && !Config_getBool(DISABLE_INDEX))
   {
     ol.endContents();
     endFileWithNavPath(getOuterScope(),ol);
@@ -230,12 +229,20 @@ void PageDef::writePageDocumentation(OutputList &ol)
   }
 
   ol.startTextBlock();
+  QCString docStr = documentation()+inbodyDocumentation();
+  if (!docStr.isEmpty())
+  {
+    ol.pushGeneratorState();
+    ol.disableAllBut(OutputGenerator::Man);
+    ol.writeString(" - ");
+    ol.popGeneratorState();
+  }
   ol.generateDoc(
       docFile(),           // fileName
       docLine(),           // startLine
       this,                // context
       0,                   // memberdef
-      documentation()+inbodyDocumentation(), // docStr
+      docStr,              // docStr
       TRUE,                // index words
       FALSE                // not an example
       );
@@ -281,7 +288,7 @@ void PageDef::writePageDocumentation(OutputList &ol)
 
 bool PageDef::visibleInIndex() const
 {
-  static bool externalPages = Config_getBool("EXTERNAL_PAGES");
+  static bool externalPages = Config_getBool(EXTERNAL_PAGES);
   return // not part of a group
          !getGroupDef() && 
          // not an externally defined page
@@ -309,6 +316,6 @@ void PageDef::setNestingLevel(int l)
 
 void PageDef::setShowToc(bool b)
 {
-  m_showToc = b;
+  m_showToc |= b;
 }
 
