@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2014 by Dimitri van Heesch.
+ * Copyright (C) 1997-2015 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -147,6 +147,10 @@ class ParserManager
      */
     ParserManager()
       : m_defaultParser(0) { m_parsers.setAutoDelete(TRUE); }
+   ~ParserManager()
+    {
+      delete m_defaultParser;
+    }
 
     void registerDefaultParser(ParserInterface *parser)
     {
