@@ -20,15 +20,28 @@
 #include "config.h"
 #include "memberdef.h"
 #include "groupdef.h"
+#include "doxygen.h"
 #include "filedef.h"
 
 #include <qstringlist.h>
 #include <string.h>
+#include <qfile.h>
 
 static QCString makeFileName(const char * withoutExtension)
 {
-  if (!withoutExtension) return QCString();
-  return QCString(withoutExtension)+".html";
+  QCString result=withoutExtension;
+  if (!result.isEmpty())
+  {
+    if (result.at(0)=='!') // relative URL -> strip marker
+    {
+      result=result.mid(1);
+    }
+    else // add specified HTML extension
+    {
+      result+=Doxygen::htmlFileExtension;
+    }
+  }
+  return result;
 }
 
 static QCString makeRef(const char * withoutExtension, const char * anchor)
@@ -40,7 +53,7 @@ static QCString makeRef(const char * withoutExtension, const char * anchor)
   return result+"#"+anchor;
 }
 
-Qhp::Qhp() : m_prevSectionLevel(0), m_sectionLevel(0)
+Qhp::Qhp() : m_prevSectionLevel(0), m_sectionLevel(0), m_skipMainPageSection(FALSE)
 {
   m_doc.setIndentLevel(0);
   m_toc.setIndentLevel(2);
@@ -68,8 +81,10 @@ void Qhp::initialize()
       <filterAttribute>1.0</filterAttribute>
   ..
   */
-  QCString nameSpace       = Config_getString("QHP_NAMESPACE");
-  QCString virtualFolder   = Config_getString("QHP_VIRTUAL_FOLDER");
+  QCString nameSpace       = Config_getString(QHP_NAMESPACE);
+  QCString virtualFolder   = Config_getString(QHP_VIRTUAL_FOLDER);
+
+  m_doc.declaration("1.0", "UTF-8");
 
   const char * rootAttributes[] =
   { "version", "1.0", 0 };
@@ -79,14 +94,14 @@ void Qhp::initialize()
   m_doc.openCloseContent("virtualFolder", virtualFolder);
 
   // Add custom filter
-  QCString filterName = Config_getString("QHP_CUST_FILTER_NAME");
+  QCString filterName = Config_getString(QHP_CUST_FILTER_NAME);
   if (!filterName.isEmpty())
   {
     const char * tagAttributes[] = 
     { "name", filterName, 0 };
     m_doc.open("customFilter", tagAttributes);
 
-    QStringList customFilterAttributes = QStringList::split(QChar(' '), Config_getString("QHP_CUST_FILTER_ATTRS"));
+    QStringList customFilterAttributes = QStringList::split(QChar(' '), Config_getString(QHP_CUST_FILTER_ATTRS));
     for (int i = 0; i < (int)customFilterAttributes.count(); i++)
     {
       m_doc.openCloseContent("filterAttribute", customFilterAttributes[i].utf8());
@@ -98,7 +113,7 @@ void Qhp::initialize()
 
   // Add section attributes
   QStringList sectionFilterAttributes = QStringList::split(QChar(' '),
-      Config_getString("QHP_SECT_FILTER_ATTRS"));
+      Config_getString(QHP_SECT_FILTER_ATTRS));
   if (!sectionFilterAttributes.contains(QString("doxygen")))
   {
     sectionFilterAttributes << "doxygen";
@@ -112,12 +127,14 @@ void Qhp::initialize()
 
   // Add extra root node
   QCString fullProjectname = getFullProjectName();
+  QCString indexFile = "index"+Doxygen::htmlFileExtension;
   const char * const attributes[] =
   { "title", fullProjectname,
-    "ref",   "index.html",
+    "ref",   indexFile,
     NULL
   };
   m_toc.open("section", attributes);
+  m_prevSectionTitle = getFullProjectName();
   m_prevSectionLevel = 1;
   m_sectionLevel = 1;
 
@@ -147,7 +164,7 @@ void Qhp::finalize()
   m_doc.close("filterSection");
   m_doc.close("QtHelpProject");
 
-  QCString fileName = Config_getString("HTML_OUTPUT") + "/" + getQhpFileName();
+  QCString fileName = Config_getString(HTML_OUTPUT) + "/" + getQhpFileName();
   QFile file(fileName);
   if (!file.open(IO_WriteOnly))
   {
@@ -160,14 +177,13 @@ void Qhp::finalize()
 void Qhp::incContentsDepth()
 {
   m_sectionLevel++;
-  //printf("Qhp::incContentsDepth() %d->%d\n",m_sectionLevel-1,m_sectionLevel);
 }
 
 void Qhp::decContentsDepth()
 {
-  //printf("Qhp::decContentsDepth() %d->%d\n",m_sectionLevel,m_sectionLevel-1);
-  if (m_sectionLevel <= 0)
+  if (m_sectionLevel<=0 || (m_sectionLevel==1 && m_skipMainPageSection))
   {
+    m_skipMainPageSection=FALSE;
     return;
   }
   m_sectionLevel--;
@@ -175,18 +191,23 @@ void Qhp::decContentsDepth()
 
 void Qhp::addContentsItem(bool /*isDir*/, const char * name, 
                           const char * /*ref*/, const char * file, 
-                          const char * /*anchor*/,bool /* separateIndex */,
+                          const char *anchor, bool /* separateIndex */,
                           bool /* addToNavIndex */,
                           Definition * /*def*/)
 {
   //printf("Qhp::addContentsItem(%s) %d\n",name,m_sectionLevel);
   // Backup difference before modification
+
+  QCString f = file;
+  if (!f.isEmpty() && f.at(0)=='^') return; // absolute URL not supported
+
   int diff = m_prevSectionLevel - m_sectionLevel;
 
   handlePrevSection();
-  setPrevSection(name, file, m_sectionLevel);
+  setPrevSection(name, f, anchor, m_sectionLevel);
 
   // Close sections as needed
+  //printf("Qhp::addContentsItem() closing %d sections\n",diff);
   for (; diff > 0; diff--)
   {
     m_toc.close("section");
@@ -194,7 +215,7 @@ void Qhp::addContentsItem(bool /*isDir*/, const char * name,
 }
 
 void Qhp::addIndexItem(Definition *context,MemberDef *md,
-                       const char *word)
+                       const char *sectionAnchor,const char *word)
 {
   (void)word;
   //printf("addIndexItem(%s %s %s\n",
@@ -204,7 +225,7 @@ void Qhp::addIndexItem(Definition *context,MemberDef *md,
 
   if (md) // member
   {
-    static bool separateMemberPages = Config_getBool("SEPARATE_MEMBER_PAGES");
+    static bool separateMemberPages = Config_getBool(SEPARATE_MEMBER_PAGES);
     if (context==0) // global member
     {
       if (md->getGroupDef())
@@ -218,7 +239,7 @@ void Qhp::addIndexItem(Definition *context,MemberDef *md,
     QCString level1  = context->name();
     QCString level2  = word ? QCString(word) : md->name();
     QCString contRef = separateMemberPages ? cfname : cfiname;
-    QCString anchor  = md->anchor();
+    QCString anchor  = sectionAnchor ? QCString(sectionAnchor) : md->anchor();
 
     QCString ref;
 
@@ -236,10 +257,10 @@ void Qhp::addIndexItem(Definition *context,MemberDef *md,
   }
   else if (context) // container
   {
-    // <keyword name="Foo" id="Foo" ref="doc.html"/>
+    // <keyword name="Foo" id="Foo" ref="doc.html#Foo"/>
     QCString contRef = context->getOutputFileBase();
     QCString level1  = word ? QCString(word) : context->name();
-    QCString ref = makeFileName(contRef);
+    QCString ref = makeRef(contRef,sectionAnchor);
     const char * attributes[] =
     {
       "name", level1,
@@ -263,8 +284,8 @@ QCString Qhp::getQhpFileName()
 
 QCString Qhp::getFullProjectName()
 {
-  QCString projectName = Config_getString("PROJECT_NAME");
-  QCString versionText = Config_getString("PROJECT_NUMBER");
+  QCString projectName = Config_getString(PROJECT_NAME);
+  QCString versionText = Config_getString(PROJECT_NUMBER);
   if (projectName.isEmpty()) projectName="Root";
   return projectName + (versionText.isEmpty()
       ? QCString("")
@@ -289,9 +310,9 @@ void Qhp::handlePrevSection()
   }
 
   // We skip "Main Page" as our extra root is pointing to that
-  if (!((m_prevSectionLevel==1) && (m_prevSectionTitle=="Main Page")))
+  if (!((m_prevSectionLevel==1) && (m_prevSectionTitle==getFullProjectName())))
   {
-    QCString finalRef = makeFileName(m_prevSectionRef);
+    QCString finalRef = makeRef(m_prevSectionBaseName, m_prevSectionAnchor);
 
     const char * const attributes[] =
     { "title", m_prevSectionTitle,
@@ -310,21 +331,27 @@ void Qhp::handlePrevSection()
       m_toc.openClose("section", attributes);
     }
   }
+  else
+  {
+    m_skipMainPageSection=TRUE;
+  }
 
   clearPrevSection();
 }
 
-void Qhp::setPrevSection(const char * title, const char * ref, int level)
+void Qhp::setPrevSection(const char * title, const char * basename, const char * anchor, int level)
 {
   m_prevSectionTitle = title;
-  m_prevSectionRef   = ref;
+  m_prevSectionBaseName = basename;
+  m_prevSectionAnchor = anchor;
   m_prevSectionLevel = level;
 }
 
 void Qhp::clearPrevSection()
 {
   m_prevSectionTitle.resize(0);
-  m_prevSectionRef.resize(0);
+  m_prevSectionBaseName.resize(0);
+  m_prevSectionAnchor.resize(0);
 }
 
 void Qhp::addFile(const char * fileName)
