@@ -163,7 +163,7 @@ class TranslatorFrench : public Translator
     /*! header that is put before the list of member attributes. */
        virtual QCString trMemberDataDocumentation()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Documentation des champs";
          }
@@ -230,7 +230,7 @@ class TranslatorFrench : public Translator
     /*! This is put above each page as a link to the list of annotated classes */
        virtual QCString trCompoundList()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Structures de données";
          }
@@ -247,7 +247,7 @@ class TranslatorFrench : public Translator
     /*! This is put above each page as a link to all members of compounds. */
        virtual QCString trCompoundMembers()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Champs de donnée";
          }
@@ -260,7 +260,7 @@ class TranslatorFrench : public Translator
     /*! This is put above each page as a link to all members of files. */
        virtual QCString trFileMembers()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Variables globale";
          }
@@ -301,7 +301,7 @@ class TranslatorFrench : public Translator
        virtual QCString trCompoundListDescription()
       {
 
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Liste des structures de données avec une brève description :";
          }
@@ -316,7 +316,7 @@ class TranslatorFrench : public Translator
        virtual QCString trCompoundMembersDescription(bool extractAll)
       {
          QCString result="Liste de tous les ";
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             result+="champs de structure et d'union ";
          }
@@ -331,7 +331,7 @@ class TranslatorFrench : public Translator
          result+="avec des liens vers ";
          if (!extractAll)
          {
-            if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+            if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
             {
                result+="la documentation de structure/union de chaque champ :";
             }
@@ -342,7 +342,7 @@ class TranslatorFrench : public Translator
          }
          else
          {
-            if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+            if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
             {
                result+="les structures/unions auxquelles ils appartiennent :";
             }
@@ -359,7 +359,7 @@ class TranslatorFrench : public Translator
       {
          QCString result="Liste ";
 
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             result+="de toutes les fonctions, variables, macros, enumérations, et définitions de type ";
          }
@@ -409,7 +409,7 @@ class TranslatorFrench : public Translator
      */
        virtual QCString trCompoundIndex()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Index des structures de données";
          }
@@ -436,7 +436,7 @@ class TranslatorFrench : public Translator
      */
        virtual QCString trClassDocumentation()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Documentation des structures de données";
          }
@@ -539,7 +539,7 @@ class TranslatorFrench : public Translator
      */
        virtual QCString trCompounds()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Structures de données";
          }
@@ -951,7 +951,7 @@ class TranslatorFrench : public Translator
       }
        virtual QCString trPublicAttribs()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Champs de données";
          }
@@ -1146,7 +1146,7 @@ class TranslatorFrench : public Translator
     /*! Used for Java classes in the summary section of Java packages */
        virtual QCString trClasses()
       {
-         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+         if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
          {
             return "Structures de données";
          }
