@@ -72,7 +72,7 @@ class TranslatorSlovak : public Translator
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dokumentácia k položkám";
       }
@@ -141,7 +141,7 @@ class TranslatorSlovak : public Translator
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dátové štruktúry";
       }
@@ -158,7 +158,7 @@ class TranslatorSlovak : public Translator
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dátové položky";
       }
@@ -171,7 +171,7 @@ class TranslatorSlovak : public Translator
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Globálne symboly";
       }
@@ -211,7 +211,7 @@ class TranslatorSlovak : public Translator
     /*! This is an introduction to the annotated compound list. */
     virtual QCString trCompoundListDescription()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Nasledujúci zoznam obsahuje identifikáciu dátových "
                "štruktúr a ich stručné popisy:";
@@ -235,7 +235,7 @@ class TranslatorSlovak : public Translator
         result += "dokumentovaných ";
       }
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result += "položiek štruktúr (struct) a unionov (union) ";
       }
@@ -248,7 +248,7 @@ class TranslatorSlovak : public Translator
 
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result += "dokumentáciu štruktúr/unionov, ku ktorým prislúchajú:";
         }
@@ -259,7 +259,7 @@ class TranslatorSlovak : public Translator
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="štruktúry/uniony, ku ktorým prislúchajú:";
         }
@@ -278,7 +278,7 @@ class TranslatorSlovak : public Translator
       QCString result="Tu nájdete zoznam všetkých ";
       if (!extractAll) result+="dokumentovaných ";
 
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="funkcií, premenných, makier, enumerácií a definícií typov (typedef) "
                 "s odkazmi na ";
@@ -334,7 +334,7 @@ class TranslatorSlovak : public Translator
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Register dátových štruktúr";
       }
@@ -455,7 +455,7 @@ class TranslatorSlovak : public Translator
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dátové štruktúry";
       }
@@ -877,7 +877,7 @@ class TranslatorSlovak : public Translator
     }
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Dátové položky";
       }
